Miscellaneous
=============

.. currentmodule:: sounddevice

.. autosummary::
   :nosignatures:

   sleep
   get_portaudio_version
   CallbackFlags
   CallbackStop
   CallbackAbort
   PortAudioError

.. autofunction:: sleep

.. autofunction:: get_portaudio_version

.. autoclass:: CallbackFlags
   :members:

.. autoexception:: CallbackStop

.. autoexception:: CallbackAbort

.. autoexception:: PortAudioError
